@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-nodeenv_version = '0.5.2'
+nodeenv_version = '0.5.3'
 
 import sys
 import os
@@ -329,9 +329,9 @@ def install_npm(env_dir, src_dir, opt):
     """
     logger.info(' * Install npm.js (%s) ... ' % opt.npm,
                     extra=dict(continued=True))
-    cmd = ['. %s && curl %s | clean=%s npm_install=%s bash && deactivate_node' % (
+    cmd = ['. %s && curl --insecure --silent %s | clean=%s npm_install=%s bash && deactivate_node' % (
             join(env_dir, 'bin', 'activate'),
-            'http://npmjs.org/install.sh',
+            'https://npmjs.org/install.sh',
             'no' if opt.no_npm_clean else 'yes',
             opt.npm)]
     callit(cmd, opt.verbose, True)
@@ -433,8 +433,9 @@ def get_last_stable_node_version():
     Return last stable node.js version
     """
     p = subprocess.Popen(
-        "curl -s http://nodejs.org/dist/ | "
-        "egrep -o '[0-9]+\.[2468]+\.[0-9]+' | "
+        "curl -s http://nodejs.org/dist/latest/ | "
+        "egrep -o 'node-v[0-9]+\.[0-9]+\.[0-9]+' | "
+        "sed -e 's/node-v//' | "
         "sort -u -k 1,1n -k 2,2n -k 3,3n -t . | "
         "tail -n1",
         shell=True, stdout=subprocess.PIPE)
